@@ -205,8 +205,11 @@ class TestBitbake:
             "artifacts": [],
             "environment": {},
             "local_conf": [],
-            "targets": None,
+            "targets": [
+                "rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test"
+            ],
             "name": "",
+            "no_cache": False,
             "bblayers_conf": [],
             "container": bitbake.build_definition.container,
             "manifest": None,
@@ -234,8 +237,11 @@ class TestBitbake:
                     "url": "https://github.com/96boards/oe-rpb-manifest.git",
                 },
                 "target": "rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test",
-                "targets": None,
+                "targets": [
+                    "rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test"
+                ],
                 "name": "",
+                "no_cache": False,
                 "artifacts": [],
                 "environment": {},
                 "local_conf": [],
@@ -905,6 +911,21 @@ class TestResults:
             params=None,
         )
 
+    def test_get_oebuild(self, results, response, get, mocker):
+        response._content = b'{"a": "b"}'
+
+        assert response.status_code == 200
+        assert results.get_oebuild() == {"a": "b"}
+        get.assert_called_with(
+            results.tuxapi_url
+            + "/v1/groups/{}/projects/{}/oebuilds/{}".format(
+                results.group, results.project, results.uid
+            ),
+            headers=results.headers,
+            timeout=mocker.ANY,
+            params=None,
+        )
+
     def test_get_test(self, results, response, get, mocker):
         url = results.tuxapi_url + "/v1/groups/{}/projects/{}/tests/{}".format(
             results.group, results.project, results.uid
@@ -931,7 +952,7 @@ class TestResults:
 
         result = results.get_all()
         assert response.status_code == 200
-        assert get.call_count == 3
+        assert get.call_count == 4
         assert isinstance(result, type(()))
 
 
