@@ -1171,6 +1171,46 @@ sample_build_result = {
     "warnings_count": 0,
 }
 
+sample_oebuild_result = {
+    "artifacts": [],
+    "bblayers_conf": [],
+    "container": "ubuntu-20.04",
+    "distro": "rpb",
+    "download_url": "https://oebuilds.tuxbuild.com/29EbSycpmLu8Nut5SoZFCwJaRER/",
+    "duration": 7021,
+    "environment": {},
+    "envsetup": "setup-environment",
+    "errors_count": 0,
+    "finished_time": "2022-05-16T08:06:04.740891",
+    "local_conf": [],
+    "machine": "dragonboard-845c",
+    "manifest_file": None,
+    "name": None,
+    "plan": "29EbSmPfjpbYQj8ZuaBpsiA8CbW",
+    "project": "tuxsuite/alok",
+    "provisioning_time": "2022-05-16T06:06:35.312683",
+    "result": "pass",
+    "running_time": "2022-05-16T06:09:04.709211",
+    "sources": {
+        "repo": {
+            "branch": "qcom/dunfell",
+            "manifest": "default.xml",
+            "url": "https://github.com/96boards/oe-rpb-manifest.git",
+        }
+    },
+    "state": "finished",
+    "status_message": "",
+    "target": "rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test",
+    "targets": [
+        "rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test"
+    ],
+    "uid": "1sMUTVjE25tQvDmjJ8SjWblpOJr",
+    "user": "alok.ranjan@linaro.org",
+    "user_agent": "tuxsuite/0.43.10",
+    "waited_by": [],
+    "warnings_count": 0,
+}
+
 
 sample_test_result = {
     "project": "ci",
@@ -1227,6 +1267,16 @@ sample_plan_result = {
     "tests": {"1": sample_test_result},
 }
 
+sample_oe_plan_result = {
+    "builds": {
+        "1": sample_oebuild_result,
+        "2": {**sample_oebuild_result, **dict({"warnings_count": 1})},
+        "3": {**sample_oebuild_result, **dict({"warnings_count": 3})},
+        "4": {**sample_oebuild_result, **dict({"result": "fail", "errors_count": 1})},
+    },
+    "tests": {},
+}
+
 sample_plan_status = {
     "builds": {
         "1sewrBhxNVbsURAKBjeXX8pyjwY": sample_build_result,
@@ -1245,6 +1295,14 @@ def build_result(tmp_path):
     return build_json
 
 
+@pytest.fixture
+def oebuild_result(tmp_path):
+    build_json = tmp_path / "oebuild_result.json"
+    with build_json.open("w") as f:
+        f.write(json.dumps(sample_oebuild_result))
+    return build_json
+
+
 @pytest.fixture
 def test_result(tmp_path):
     test_json = tmp_path / "test_result.json"
@@ -1281,6 +1339,7 @@ def test_results_cli(
     test_result,
     build_set_result,
     plan_result,
+    oebuild_result,
 ):
     results = mocker.patch(
         "tuxsuite.Results.get_all", return_value=(sample_all_result, "http://api")
@@ -1347,6 +1406,48 @@ tests (1): 👹 1
 """
     )
 
+    mocker.resetall()
+    results = mocker.patch(
+        "tuxsuite.Results.get_plan", return_value=(sample_oe_plan_result, "http://api")
+    )
+    result = runner.invoke(
+        tuxsuite.cli.results,
+        [
+            "--plan=29EbSmPfjpbYQj8ZuaBpsiA8CbW",
+        ],
+    )
+    assert result.exit_code == 0
+    assert results.call_count == 1
+    assert (
+        result.output
+        == """Summary: https://tuxapi.tuxsuite.com/v1/groups/tuxsuite/projects/tux/plans/29EbSmPfjpbYQj8ZuaBpsiA8CbW
+1sMUTVjE25tQvDmjJ8SjWblpOJr 🎉 Pass with container: ubuntu-20.04 machine: dragonboard-845c \
+targets: ['rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test']
+1sMUTVjE25tQvDmjJ8SjWblpOJr 👾 Pass (1 warning) with container: ubuntu-20.04 machine: dragonboard-845c \
+targets: ['rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test']
+1sMUTVjE25tQvDmjJ8SjWblpOJr 👾 Pass (3 warnings) with container: ubuntu-20.04 machine: dragonboard-845c \
+targets: ['rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test']
+1sMUTVjE25tQvDmjJ8SjWblpOJr 👹 Fail (1 error) with container: ubuntu-20.04 machine: dragonboard-845c \
+targets: ['rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test']
+builds (4): 🎉 1 👾 2 👹 1
+tests (0):
+"""
+    )
+    mocker.resetall()
+    results = mocker.patch(
+        "tuxsuite.Results.get_oebuild", return_value=sample_oebuild_result
+    )
+    result = runner.invoke(
+        tuxsuite.cli.results,
+        [
+            "--oebuild=1sMUTVjE25tQvDmjJ8SjWblpOJr",
+            f"--json-out={tmp_path}/oebuild_result.json",
+        ],
+    )
+    assert result.exit_code == 0
+    assert results.call_count == 1
+    assert format_result.call_count == 1
+
     mocker.resetall()
     results = mocker.patch(
         "tuxsuite.Results.get_build", return_value=sample_build_result
@@ -1361,6 +1462,20 @@ tests (1): 👹 1
     assert results.call_count == 1
     assert format_result.call_count == 1
 
+    mocker.resetall()
+    results = mocker.patch(
+        "tuxsuite.Results.get_oebuild", return_value=sample_oebuild_result
+    )
+    result = runner.invoke(
+        tuxsuite.cli.results,
+        [
+            f"--from-json={oebuild_result}",
+        ],
+    )
+    assert result.exit_code == 0
+    assert results.call_count == 1
+    assert format_result.call_count == 1
+
     mocker.resetall()
     results = mocker.patch(
         "tuxsuite.Results.get_test", return_value=(sample_test_result, "http://api")
