@@ -181,7 +181,7 @@ class TestBackwardsCompatibilityWithTuxBuild:
             "sets:\n  - name: basic\n    builds:\n      - {target_arch: arm64, toolchain: gcc-10, kconfig: defconfig}"
         )
         c = tuxsuite.config.BuildSetConfig("basic")
-        assert len(c.entries) == 1
+        assert len(c.plan) == 1
         assert "~/.config/tuxbuild/builds.yaml is deprecated" in caplog.text
 
     def test_TUXBUILD_ENV(self, monkeypatch, config_file, caplog, tuxauth):
