@@ -5,7 +5,7 @@
 This is the tuxsuite module.
 """
 
-__version__ = "0.47.0"
+__version__ = "0.48.0"
 
 
 from . import build
@@ -218,6 +218,8 @@ class BakePlan(PlanType):
 
     def create_builds(self, plan, builds):
         req_data = {"oebuilds": []}
+        # handling no-cache option
+        no_cache = plan.args.get("no_cache", False)
         # Ignoring kernel plan build options
         data = {
             key: value
@@ -237,6 +239,7 @@ class BakePlan(PlanType):
         for cfg in plan.config.plan:
             if cfg["build"] is not None:
                 data["data"] = cfg["build"]
+                data["data"]["no_cache"] = no_cache
                 builds.append(build.Bitbake(**data))
             else:
                 builds.append(None)
