@@ -566,35 +566,79 @@ class Plan(HeadersMixin):
             tests_status.update({test.uid: test.status})
         self.status = {"builds": builds_status, "tests": tests_status}
 
-    def load(self, data):
-        for (uid, b) in data["builds"].items():
-            git_ref = b.get("git_ref")
-            git_sha = b.get("git_sha")
-            if git_ref:
-                git_sha = None
-            build = Build(
-                git_repo=b["git_repo"],
-                git_ref=git_ref,
-                git_sha=git_sha,
-                target_arch=b["target_arch"],
-                kconfig=b["kconfig"],
-                toolchain=b["toolchain"],
-                token=self.token,
-                kbapi_url=None,
-                tuxapi_url=self.tuxapi_url,
-                group=self.group,
-                project=b["project"],
-                environment=b.get("environment"),
-                targets=b.get("targets"),
-                make_variables=b.get("make_variables"),
-                kernel_image=b.get("kernel_image"),
-                build_data=b.get("build_data"),
-                build_name=b.get("build_name"),
-                status=b,
-                uid=b["uid"],
-            )
-            self.builds.append(build)
+    def load_kernel_builds(self, b):
+        git_ref = b.get("git_ref")
+        git_sha = b.get("git_sha")
+        if git_ref:
+            git_sha = None
+        build = Build(
+            git_repo=b["git_repo"],
+            git_ref=git_ref,
+            git_sha=git_sha,
+            target_arch=b["target_arch"],
+            kconfig=b["kconfig"],
+            toolchain=b["toolchain"],
+            token=self.token,
+            kbapi_url=None,
+            tuxapi_url=self.tuxapi_url,
+            group=self.group,
+            project=b["project"],
+            environment=b.get("environment"),
+            targets=b.get("targets"),
+            make_variables=b.get("make_variables"),
+            kernel_image=b.get("kernel_image"),
+            build_data=b.get("build_data"),
+            build_name=b.get("build_name"),
+            status=b,
+            uid=b["uid"],
+        )
+        return build
 
+    def load_bake_builds(self, b):
+        build_definition = {
+            key: val
+            for key, val in b.items()
+            if key
+            in [
+                "envsetup",
+                "distro",
+                "machine",
+                "sources",
+                "environment",
+                "artifacts",
+                "local_conf",
+                "bblayers_conf",
+                "manifest",
+                "container",
+                "targets",
+                "target",
+            ]
+        }
+        oebuild = Bitbake(
+            token=self.token,
+            kbapi_url=None,
+            tuxapi_url=self.tuxapi_url,
+            group=self.group,
+            project=b["project"],
+            build_data=b.get("build_data"),
+            status=b,
+            uid=b["uid"],
+            manifest=b.get("manifest"),
+            data=build_definition,
+        )
+        return oebuild
+
+    def load(self, data):
+        # builds --> kernel or bake
+        for (uid, b) in data["builds"].items():
+            if "build_name" in b:
+                build = self.load_kernel_builds(b)
+                self.builds.append(build)
+            elif "sources" in b:
+                oebuild = self.load_bake_builds(b)
+                self.builds.append(oebuild)
+
+        # tests
         for (uid, t) in data["tests"].items():
             test = Test(
                 device=t["device"],
@@ -938,6 +982,12 @@ class Results(HeadersMixin):
         result = get_request(url, self.headers)
         return (result, url)
 
+    def get_oebuild(self):
+        url = self.tuxapi_url + "/v1/groups/{}/projects/{}/oebuilds/{}".format(
+            self.group, self.project, self.uid
+        )
+        return get_request(url, self.headers)
+
     def get_plan(self):
         plan = Plan(
             None,
@@ -956,12 +1006,13 @@ class Results(HeadersMixin):
         url = self.tuxapi_url + "/v1/groups/{}/projects/{}".format(
             self.group, self.project
         )
-        build_url = url + "/builds"
+        # availables builds and tests
+        result_types = ["builds", "tests", "plans", "oebuilds"]
+        for res_type in result_types:
+            type_url = url + f"/{res_type}"
+            all_results[res_type] = get_request(type_url, self.headers)
+
         test_url = url + "/tests"
-        plan_url = url + "/plans"
-        all_results["builds"] = get_request(build_url, self.headers)
-        all_results["tests"] = get_request(test_url, self.headers)
-        all_results["plans"] = get_request(plan_url, self.headers)
         return (all_results, test_url)
 
 
@@ -994,9 +1045,25 @@ class Bitbake(HeadersMixin):
         container = attrib(default="ubuntu-20.04")
         manifest = attrib(default=None)
         name = attrib(default="")
+        no_cache = attrib(default=False)
 
     def __attrs_post_init__(self):
         self.build_definition = self.BuildDefinition(**(self.data))
+        # TODO: Temp legacy target fixes, to be removed after we deprecate target
+        try:
+            if (
+                self.build_definition.targets is None
+                and self.build_definition.target is not None
+            ):
+                if not isinstance(self.build_definition.target, str):
+                    raise Exception(
+                        f"Unexpected argument for target: {self.build_definition.target}, expected string"
+                    )
+                else:
+                    self.build_definition.targets = [self.build_definition.target]
+        except Exception as e:
+            sys.stderr.write(f"{str(e)}\n")
+            sys.exit(1)
 
     # Currently of no use but needed for Plan filters(passing, warnings, failings etc.)
     def __lt__(self, other):
@@ -1007,7 +1074,7 @@ class Bitbake(HeadersMixin):
             self.build_definition.sources,
             self.build_definition.distro,
             self.build_definition.machine,
-            self.build_definition.target,
+            self.build_definition.targets,
             self.build_data,
         )
 
