@@ -151,7 +151,7 @@ def format_build(build, icon, color, msg):
     # key: string, value: list ( list can't be empty)
     build_type_map = {
         "Build": ["toolchain", "target_arch"],
-        "Bitbake": ["container", "machine", "target"],
+        "Bitbake": ["container", "machine", "targets"],
     }
     # respective build type classnames for kernel or bake builds
     build_type = build.__class__.__name__
@@ -260,12 +260,12 @@ def get_result_msg(result_json, tuxapi_tests_url):
         ) and (
             result_json.get("container")
             and result_json.get("machine")
-            and result_json.get("target")
+            and result_json.get("targets")
         ):
             result_msg = (
                 f"with container: {result_json['container']}, "
                 f"machine: {result_json['machine']} and "
-                f"target: {result_json['target']}  @ {result_json['download_url']}"
+                f"targets: {result_json['targets']}  @ {result_json['download_url']}"
             )
         elif result_json["sources"].get("kas") and result_json.get("container"):
             result_msg = (
@@ -603,6 +603,12 @@ def bake():
     default=".",
     help="Directory where to download artifacts",
 )
+@click.option(
+    "--no-cache",
+    default=False,
+    is_flag=True,
+    help="Build without using any compilation cache",
+)
 def submit(
     build_definition,
     json_out=None,
@@ -610,6 +616,7 @@ def submit(
     no_wait=False,
     download=False,
     output_dir=None,
+    no_cache=False,
 ):
     try:
         with open(os.path.abspath(build_definition)) as reader:
@@ -621,14 +628,17 @@ def submit(
         sys.exit(1)
     if local_manifest:
         data["manifest"] = click.format_filename(local_manifest)
+
+    data["no_cache"] = no_cache
+
     try:
         build = tuxsuite.Bitbake(data=data)
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
         error(e)
     info(
         "*** WARNING: BITBAKE SUPPORT IS EXPERIMENTAL ***\n"
-        "Building target: {} with bitbake from {} source with distro: {} machine: {} arguments".format(
-            build.build_definition.target,
+        "Building targets: {} with bitbake from {} source with distro: {} machine: {} arguments".format(
+            build.build_definition.targets,
             build.build_definition.sources,
             build.build_definition.distro,
             build.build_definition.machine,
@@ -1264,6 +1274,9 @@ def plan(
 @click.option("--build", help="UID of the build to fetch result", default="", type=str)
 @click.option("--test", help="UID of the test to fetch result", default="", type=str)
 @click.option("--plan", help="UID of the plan to fetch result", default="", type=str)
+@click.option(
+    "--oebuild", help="UID of the oebuild to fetch result", default="", type=str
+)
 @click.option(
     "--from-json",
     help="Read status input from named json file path",
@@ -1274,7 +1287,7 @@ def plan(
     help="Write json results out to a named file path",
     type=click.File("w", encoding="utf-8"),
 )
-def results(build, test, plan, from_json, json_out):
+def results(build, test, plan, oebuild, from_json, json_out):
     result_json = {}
     try:
         results = tuxsuite.Results()
@@ -1290,7 +1303,10 @@ def results(build, test, plan, from_json, json_out):
                 build = data["uid"]
             elif "tests" in data:
                 test = data["uid"]
+            elif "sources" in data:
+                oebuild = data["uid"]
             elif isinstance(data, list):
+                # TODO: ---> for bake required or not ?
                 result_json = []
                 for res in data:
                     results.uid = res["uid"]
@@ -1298,7 +1314,7 @@ def results(build, test, plan, from_json, json_out):
                     format_result(build_result)
                     if json_out:
                         result_json.append(build_result)
-        elif not any([build, test, plan]):  # get all results with no options
+        elif not any([build, test, plan, oebuild]):  # get all results with no options
             result_json, tuxapi_tests_url = results.get_all()
             for key in result_json.keys():
                 info(f"{key.capitalize()}:")
@@ -1319,7 +1335,6 @@ def results(build, test, plan, from_json, json_out):
         if plan:
             results.uid = plan
             result_json, tuxapi_plan_url = results.get_plan()
-
             plan_obj = tuxsuite.Plan("")
             plan_obj.plan = plan
             plan_obj.load(result_json)
@@ -1336,6 +1351,10 @@ def results(build, test, plan, from_json, json_out):
             (build_summary, test_summary) = plan_summary(plan_obj)
             info(build_summary)
             info(test_summary)
+        if oebuild:
+            results.uid = oebuild
+            result_json = results.get_oebuild()
+            format_result(result_json)
 
     except tuxsuite.exceptions.URLNotFound as e:
         raise (click.ClickException(str(e)))
